def print_lol(the_list,level):
    for each_item in the_list:
	    if isinstance(each_item,list):
		    print_lol(each_item,level+1)
	    else:
                    for tab_stop in range(level):
                        print('\t',end='')
		    print(each_item)



from distutils.core import setup
setup(
      name='Cindxu',
      version='1.1.0',
      py_modules=['Cindxu'],
      author='xuli',
      author_email='xulicindy@163.com',
      url='http://www.headfirstlabs.com',
      description='A simple printer of nested lists for specific tab',
      )
